package riciclaggio;

import riciclaggio.Materiale.TipoMateriale;

public class Riciclaggio {
	
	private static final int MAX_MATERIALI = 200;
	private static final int MAX_PUNTI = 5000;
		
	private static Materiale[] materiali;
	private static Punto[] punti;
	private static int numMateriali; // contiene il numero di materiali correntemente nel vettore
	private static int numPunti; // contiene il numero di punti correntemente nel vettore
	
	static{
		materiali = new Materiale[MAX_MATERIALI];
		punti = new Punto[MAX_PUNTI];
		numMateriali = 0;
		numPunti = 0;
	}
	
	public static boolean inserisciPunto(Punto p){
		boolean inserito = false;
		
		if(numPunti < MAX_PUNTI){
			punti[numPunti++]=p;
			inserito=true;
		}
		return(inserito);
	}
	
	public static boolean inserisciMateriale(Materiale m){
		boolean espansione=false;
		
		if(numMateriali == materiali.length){
			expand();
			espansione = true;
		}
		materiali[numMateriali++]=m;
		return(espansione);
	}
	
	private static void expand(){
		int n = materiali.length*130/100;
		Materiale[] temp = new Materiale[n];
		for(int i=0;i<numMateriali;i++)
			temp[i]=materiali[i];
		materiali=temp;
	}
	
	public static int materialiEconomiciPerTipo(TipoMateriale tipo, double costoMassimo){
		int numStampati=0;
		
		for(int i=0; i<numMateriali; i++){
			if(materiali[i].getCostoRicicloAlKg() < costoMassimo){
				switch(tipo){
				case BIOLOGICO:
					if(materiali[i] instanceof MaterialeBiologico){
						System.out.println(materiali[i]); // chiamata implicita al metodo toString()
						numStampati++;
					}
					break;
				case SINTETICO:
					if(materiali[i] instanceof MaterialeSintetico){
						System.out.println(materiali[i]); // chiamata implicita al metodo toString()
						numStampati++;
					}
					break;
				case METALLO:
					if(materiali[i] instanceof MaterialeMetallo){
						System.out.println(materiali[i]); // chiamata implicita al metodo toString()
						numStampati++;
					}		
				}// end switch
			} // end if
		} // end for
		return(numStampati);
	}	
	
	/* 
	 * VERSIONE ALTERNATIVA
	 * 
	public static int materialiEconomiciPerTipo(TipoMateriale tipo, double costoMassimo){
		int numStampati=0;
		
		switch(tipo){
			case BIOLOGICO:
				for(int i=0; i<numMateriali; i++)
					if(materiali[i] instanceof MaterialeBiologico && materiali[i].getCostoRicicloAlKg() < costoMassimo){
						System.out.println(materiali[i]); // chiamata implicita al metodo toString()
						numStampati++;
					}
				break;
			case SINTETICO:
				for(int i=0; i<numMateriali; i++)
					if(materiali[i] instanceof MaterialeSintetico && materiali[i].getCostoRicicloAlKg() < costoMassimo){
						System.out.println(materiali[i]); // chiamata implicita al metodo toString()
						numStampati++;
					}
				break;
			case METALLO:
				for(int i=0; i<numMateriali; i++)
					if(materiali[i] instanceof MaterialeMetallo && materiali[i].getCostoRicicloAlKg() < costoMassimo){
						System.out.println(materiali[i]); // chiamata implicita al metodo toString()
						numStampati++;
					}		
		} // end switch
		
		return(numStampati);
	}
	
	*/
	
	
	public static DatiMateriale puntiPerMateriale(int codiceMateriale, String regione){
		TipoMateriale tipo=null; 
		DatiMateriale dati = null; 
		int numPuntiPerMateriale=0;
		int numPuntiPerRegione=0;
		
		boolean trovato=false;
		for(int i=0; i<numMateriali && !trovato; i++)
			if(materiali[i].getCodice()==codiceMateriale){
				trovato=true;
				if(materiali[i] instanceof MaterialeBiologico)
					tipo = TipoMateriale.BIOLOGICO;
				else if(materiali[i] instanceof MaterialeSintetico)
						tipo = TipoMateriale.SINTETICO;
					else
						tipo = TipoMateriale.METALLO;
			}
		if(!trovato)
			System.out.println("Materiale non presente nel vettore");
		else{
			for(int i=0; i<numPunti; i++)
				if(punti[i].getRegione().equalsIgnoreCase(regione)){
					numPuntiPerRegione++;
					if(punti[i].getTipoMaterialeRaccolto()==tipo)	
						numPuntiPerMateriale++;
				}
			if(numPuntiPerMateriale==0)
				System.out.println("Non sono presenti punti di raccolta per il materiale cercato nella regione indicata");
			else{
				double percentualePunti = (double)numPuntiPerMateriale/numPuntiPerRegione*100;
				dati = new DatiMateriale(numPuntiPerMateriale,percentualePunti);
			}
		}
		return dati;
	}
	
	/* metodi non necessari all'esecuzione del programma
	
	public static Materiale[] getMateriali(){
		return materiali;
	}
	
	public static Punto[] getPunti(){
		return punti;
	}
	
	public static int getNumMateriali(){
		return numMateriali;
	}
	
	public static int getNumPunti(){
		return numPunti;
	}
	
	public static void setMateriali(Materiale materiali[]){
		this.materiali = materiali;
	}
	
	public static void setPunti(Punto punti[]){
		this.punti = punti;
	}
	
	public static void setNumMateriali(int numMateriali){
		this.numMateriali = numMateriali;
	}
	
	public static void setNumPunti(int numPunti){ 
		this.numPunti = numPunti;
	}
	 
	*/
	
}
